#!/bin/bash


pkgname="rtlwifi"
pkgurl="https://github.com/cilynx/rtl88x2bu.git"
installcmd="dnf install"
installcmdextra="dnf group install"
pkgdeps="wget unzip dnsmasq hostapd bc dkms kernel-headers rsync"
pkgdepsextra='"Development Tools"'
tmpdir="/tmp"

_fetch_deps(){
    if [ -f /usr/bin/apt ];then
        apt install git dnsmasq hostapd bc build-essential dkms

    elif [ -f /usr/bin/dnf ];then
        dnf install unzip dnsmasq hostapd bc dkms kernel-headers rsync
    else
        echo "No supported package manager"
    fi
}


_download(){
    if [ ! -d ${tmpdir}/${pkgname} ];then
         git clone ${pkgurl} ${tmpdir}/${pkgname}
    fi
}

_apply_patch(){
	wget https://github.com/cilynx/rtl88x2bu/pull/58.patch
	git apply 58.patch
}

_install(){
    cd ${tmpdir}/${pkgname}
    _apply_patch
    VER=$(sed -n 's/\PACKAGE_VERSION="\(.*\)"/\1/p' dkms.conf)
    rsync -rvhP ./ /usr/src/rtl88x2bu-${VER}
    dkms add -m rtl88x2bu -v ${VER}
    dkms build -m rtl88x2bu -v ${VER}
    dkms install -m rtl88x2bu -v ${VER}
    modprobe 88x2bu
}

_fetch_deps
_download
_install
